@@ -1,4 +1,6 @@
   # -*- extra stuff goes here -*- 
+# Initial permissions setup.
+import permissions
 from zope.i18nmessageid import MessageFactory as BaseMessageFactory
 
 MessageFactory = BaseMessageFactory('plonetheme.arnolfini')
