@@ -538,7 +538,7 @@ Arnolfini.carouselFix = function ()
 	$("#MainContent").css("background-image", "none");
 }
 
-Arnolfini.trackEcommerce = function (title, price)
+Arnolfini.trackEcommerce = function (title, price, category)
 {
 	var d = new Date();
 	var timestamp = d.getDate().toString() + "-" + (d.getMonth() + 1) +"-"+ d.getFullYear().toString() +"-"+ d.getHours().toString() +":"+ d.getMinutes().toString();
@@ -557,7 +557,7 @@ Arnolfini.trackEcommerce = function (title, price)
 	   encodeURIComponent(title),           // transaction ID - necessary to associate item with transaction
 	   '',           // SKU/code - required
 	   title,        // product name
-	   '',   // category or variation
+	   category,   // category or variation
 	   price.toString(),          // unit price - required
 	   '1'               // quantity - required
 	]);
